@@ -1,13 +1,9 @@
 # -*- coding: utf-8 -*-
+from django.utils import formats, six
 from django.forms.util import flatatt
 from django.forms.widgets import TextInput
 from django.utils.safestring import mark_safe
-from django.utils.encoding import force_unicode
-try:
-    from django.utils import formats
-except ImportError:
-    # For Django 1.1 compatibility
-    from durationfield.utils import compat as formats
+from django.utils.encoding import force_text
 from datetime import timedelta
 
 
@@ -17,15 +13,15 @@ class DurationInput(TextInput):
         output.append(u'<li>%(cb)s<label%(for)s>%(label)s</label></li>' % {"for": label_for, "label": option_label, "cb": rendered_cb})
         """
         if value is None:
-            value = u''
+            value = ''
 
         final_attrs = self.build_attrs(attrs, type=self.input_type, name=name)
-        if value != u'':
+        if value != '':
             # Only add the 'value' attribute if a value is non-empty.
-            if isinstance(value, (int, long)):  # Database backends serving different types
+            if isinstance(value, six.integer_types):
                 value = timedelta(microseconds=value)
 
             # Otherwise, we've got a timedelta already
 
-            final_attrs['value'] = force_unicode(formats.localize_input(value))
-        return mark_safe(u'<input%s />' % flatatt(final_attrs))
+            final_attrs['value'] = force_text(formats.localize_input(value))
+        return mark_safe('<input%s />' % flatatt(final_attrs))
